@@ -51,7 +51,7 @@ fn initialize(name: &str) -> Result<PathBuf> {
     // smoelius: Try to order failures by how informative they are: failure to build the library,
     // failure to find the library, failure to build/find the driver.
 
-    dylint_internal::build().success()?;
+    dylint_internal::build(&format!("library `{}`", name), false).success()?;
 
     // smoelius: `DYLINT_LIBRARY_PATH` must be set before `dylint_libs` is called.
     // smoelius: This was true when `dylint_libs` called `name_toolchain_map`, but that is no longer
@@ -183,7 +183,7 @@ fn rustc_flags(metadata: &Metadata, package: &Package, target: &Target) -> Resul
 
         remove_example(metadata, package, target)?;
 
-        cargo::build()
+        cargo::build(&format!("example `{}`", target.name), false)
             .envs(vec![(env::CARGO_TERM_COLOR, "never")])
             .args(&[
                 "--manifest-path",
